==> ews-javascript-api-0.1.2.tgz: package/js/ComplexProperties/FolderPermissionCollection.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlNamespace_1 = require("../Enumerations/XmlNamespace");
//import CalendarFolder = require("../Core/ServiceObjects/Folders/Calendar____Folder");
var FolderPermission_1 = require("./FolderPermission");
var ComplexPropertyCollection_1 = require("./ComplexPropertyCollection");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var FolderPermissionCollection = (function (_super) {
    __extends(FolderPermissionCollection, _super);
    function FolderPermissionCollection(owner) {
        _super.call(this);
        this.unknownEntries = []; // System.Collections.ObjectModel.Collection<string>;
        this.isCalendarFolder = owner._FolderType === XmlElementNames_1.XmlElementNames.CalendarFolder; //owner instanceof CalendarFolder;
    }
    Object.defineProperty(FolderPermissionCollection.prototype, "InnerCollectionXmlElementName", {
        get: function () { return this.isCalendarFolder ? XmlElementNames_1.XmlElementNames.CalendarPermissions : XmlElementNames_1.XmlElementNames.Permissions; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FolderPermissionCollection.prototype, "CollectionItemXmlElementName", {
        get: function () { return this.isCalendarFolder ? XmlElementNames_1.XmlElementNames.CalendarPermission : XmlElementNames_1.XmlElementNames.Permission; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FolderPermissionCollection.prototype, "UnknownEntries", {
        get: function () { return this.unknownEntries; } // System.Collections.ObjectModel.Collection<string>;
        ,
        enumerable: true,
        configurable: true
    });
    FolderPermissionCollection.prototype.Add = function (permission) { this.InternalAdd(permission); };
    FolderPermissionCollection.prototype.AddRange = function (permissions /*System.Collections.Generic.IEnumerable<T>*/) {
        //EwsUtilities.ValidateParam(permissions, "permissions");
        for (var _i = 0; _i < permissions.length; _i++) {
            var permission = permissions[_i];
            this.Add(permission);
        }
    };
    FolderPermissionCollection.prototype.Clear = function () { this.InternalClear(); };
    FolderPermissionCollection.prototype.CreateComplexProperty = function (xmlElementName) { return new FolderPermission_1.FolderPermission(); };
    FolderPermissionCollection.prototype.CreateDefaultComplexProperty = function () { return new FolderPermission_1.FolderPermission(); };
    FolderPermissionCollection.prototype.GetCollectionItemXmlElementName = function (complexProperty) { return this.CollectionItemXmlElementName; };
    FolderPermissionCollection.prototype.InternalToJson = function (service) { throw new Error("FolderPermissionCollection.ts - InternalToJson : Not implemented."); };
    FolderPermissionCollection.prototype.LoadFromJson = function (jsonProperty /*JsonObject*/, service) { throw new Error("FolderPermissionCollection.ts - LoadFromJson : Not implemented."); };
    FolderPermissionCollection.prototype.LoadFromXmlJsObject = function (jsonProperty, service) {
        var jsonFolderPermissions = jsonProperty[this.InnerCollectionXmlElementName];
        if (jsonFolderPermissions && jsonFolderPermissions[this.CollectionItemXmlElementName])
            jsonFolderPermissions = jsonFolderPermissions[this.CollectionItemXmlElementName];
        if (!Array.isArray(jsonFolderPermissions)) {
            debugger;
            throw new Error("Invalid xml parsing, jsonproperty must contain collectionxmlelementname and collectionitemelementname underneeth");
        }
        for (var _i = 0; _i < jsonFolderPermissions.length; _i++) {
            var jsonFolderPermission = jsonFolderPermissions[_i];
            var permission = new FolderPermission_1.FolderPermission();
            debugger; //implement this
            permission.LoadFromXmlJsObject(jsonFolderPermission, service);
            this.InternalAdd(permission);
        }
        if (jsonProperty[XmlElementNames_1.XmlElementNames.UnknownEntries]) {
            var jsonUnknownEntries = jsonProperty[XmlElementNames_1.XmlElementNames.UnknownEntries];
            if (typeof jsonUnknownEntries !== 'object' && !Array.isArray(jsonFolderPermissions)) {
                debugger;
                throw new Error("Invalid xml returned - check for consistency, UnknownEntries must be array type");
            }
            debugger; //check for unknown entries type, shold be string or array of string
            for (var _a = 0; _a < jsonUnknownEntries.length; _a++) {
                var jsonUnknownEntry = jsonUnknownEntries[_a];
                this.unknownEntries.push(jsonUnknownEntry);
            }
        }
    };
    FolderPermissionCollection.prototype.Remove = function (permission) { return this.InternalRemove(permission); };
    FolderPermissionCollection.prototype.RemoveAt = function (index) { this.InternalRemoveAt(index); };
    FolderPermissionCollection.prototype.Validate = function () {
        for (var permissionIndex = 0; permissionIndex < this.Items.length; permissionIndex++) {
            var permission = this.Items[permissionIndex];
            permission.Validate(this.isCalendarFolder, permissionIndex);
        }
    };
    FolderPermissionCollection.prototype.WriteElementsToXml = function (writer) {
        writer.WriteStartElement(XmlNamespace_1.XmlNamespace.Types, this.InnerCollectionXmlElementName);
        for (var _i = 0, _a = this.Items; _i < _a.length; _i++) {
            var folderPermission = _a[_i];
            folderPermission.WriteToXml(writer, this.GetCollectionItemXmlElementName(folderPermission), undefined, this.isCalendarFolder);
        }
        writer.WriteEndElement(); // this.InnerCollectionXmlElementName
    };
    return FolderPermissionCollection;
})(ComplexPropertyCollection_1.ComplexPropertyCollection);
exports.FolderPermissionCollection = FolderPermissionCollection;

==> ews-javascript-api-0.1.6.tgz: package/js/ComplexProperties/FolderPermissionCollection.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlNamespace_1 = require("../Enumerations/XmlNamespace");
//import CalendarFolder = require("../Core/ServiceObjects/Folders/Calendar____Folder");
var FolderPermission_1 = require("./FolderPermission");
var ComplexPropertyCollection_1 = require("./ComplexPropertyCollection");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var FolderPermissionCollection = (function (_super) {
    __extends(FolderPermissionCollection, _super);
    function FolderPermissionCollection(owner) {
        _super.call(this);
        this.unknownEntries = []; // System.Collections.ObjectModel.Collection<string>;
        this.isCalendarFolder = owner._FolderType === XmlElementNames_1.XmlElementNames.CalendarFolder; //owner instanceof CalendarFolder;
    }
    Object.defineProperty(FolderPermissionCollection.prototype, "InnerCollectionXmlElementName", {
        get: function () { return this.isCalendarFolder ? XmlElementNames_1.XmlElementNames.CalendarPermissions : XmlElementNames_1.XmlElementNames.Permissions; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FolderPermissionCollection.prototype, "CollectionItemXmlElementName", {
        get: function () { return this.isCalendarFolder ? XmlElementNames_1.XmlElementNames.CalendarPermission : XmlElementNames_1.XmlElementNames.Permission; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FolderPermissionCollection.prototype, "UnknownEntries", {
        get: function () { return this.unknownEntries; } // System.Collections.ObjectModel.Collection<string>;
        ,
        enumerable: true,
        configurable: true
    });
    FolderPermissionCollection.prototype.Add = function (permission) { this.InternalAdd(permission); };
    FolderPermissionCollection.prototype.AddRange = function (permissions /*System.Collections.Generic.IEnumerable<T>*/) {
        //EwsUtilities.ValidateParam(permissions, "permissions");
        for (var _i = 0; _i < permissions.length; _i++) {
            var permission = permissions[_i];
            this.Add(permission);
        }
    };
    FolderPermissionCollection.prototype.Clear = function () { this.InternalClear(); };
    FolderPermissionCollection.prototype.CreateComplexProperty = function (xmlElementName) { return new FolderPermission_1.FolderPermission(); };
    FolderPermissionCollection.prototype.CreateDefaultComplexProperty = function () { return new FolderPermission_1.FolderPermission(); };
    FolderPermissionCollection.prototype.GetCollectionItemXmlElementName = function (complexProperty) { return this.CollectionItemXmlElementName; };
    FolderPermissionCollection.prototype.InternalToJson = function (service) { throw new Error("FolderPermissionCollection.ts - InternalToJson : Not implemented."); };
    FolderPermissionCollection.prototype.LoadFromJson = function (jsonProperty /*JsonObject*/, service) { throw new Error("FolderPermissionCollection.ts - LoadFromJson : Not implemented."); };
    FolderPermissionCollection.prototype.LoadFromXmlJsObject = function (jsonProperty, service) {
        var jsonFolderPermissions = jsonProperty[this.InnerCollectionXmlElementName];
        if (jsonFolderPermissions && jsonFolderPermissions[this.CollectionItemXmlElementName])
            jsonFolderPermissions = jsonFolderPermissions[this.CollectionItemXmlElementName];
        if (!Array.isArray(jsonFolderPermissions)) {
            debugger;
            throw new Error("FolderPermissionCollection.ts - LoadFromXmlJsObject - Invalid xml parsing, jsonproperty must contain collectionxmlelementname and collectionitemelementname underneeth");
        }
        for (var _i = 0; _i < jsonFolderPermissions.length; _i++) {
            var jsonFolderPermission = jsonFolderPermissions[_i];
            var permission = new FolderPermission_1.FolderPermission();
            permission.LoadFromXmlJsObject(jsonFolderPermission, service);
            this.InternalAdd(permission);
        }
        if (jsonProperty[XmlElementNames_1.XmlElementNames.UnknownEntries]) {
            var jsonUnknownEntries = jsonProperty[XmlElementNames_1.XmlElementNames.UnknownEntries];
            if (typeof jsonUnknownEntries !== 'object' && !Array.isArray(jsonFolderPermissions)) {
                debugger;
                throw new Error("FolderPermissionCollection.ts - LoadFromXmlJsObject - Invalid xml returned - check for consistency, UnknownEntries must be array type");
            }
            //debugger;//debug: //check: for unknown entries type, shold be string or array of string
            for (var _a = 0; _a < jsonUnknownEntries.length; _a++) {
                var jsonUnknownEntry = jsonUnknownEntries[_a];
                this.unknownEntries.push(jsonUnknownEntry);
            }
        }
    };
    FolderPermissionCollection.prototype.Remove = function (permission) { return this.InternalRemove(permission); };
    FolderPermissionCollection.prototype.RemoveAt = function (index) { this.InternalRemoveAt(index); };
    FolderPermissionCollection.prototype.Validate = function () {
        for (var permissionIndex = 0; permissionIndex < this.Items.length; permissionIndex++) {
            var permission = this.Items[permissionIndex];
            permission.Validate(this.isCalendarFolder, permissionIndex);
        }
    };
    FolderPermissionCollection.prototype.WriteElementsToXml = function (writer) {
        writer.WriteStartElement(XmlNamespace_1.XmlNamespace.Types, this.InnerCollectionXmlElementName);
        for (var _i = 0, _a = this.Items; _i < _a.length; _i++) {
            var folderPermission = _a[_i];
            folderPermission.WriteToXml(writer, this.GetCollectionItemXmlElementName(folderPermission), undefined, this.isCalendarFolder);
        }
        writer.WriteEndElement(); // this.InnerCollectionXmlElementName
    };
    return FolderPermissionCollection;
})(ComplexPropertyCollection_1.ComplexPropertyCollection);
exports.FolderPermissionCollection = FolderPermissionCollection;
